diff --git a/xml/src/main/java/org/springframework/xml/validation/XmlValidator.java b/xml/src/main/java/org/springframework/xml/validation/XmlValidator.java
index 0a11aae2..daea4e85 100644
--- a/xml/src/main/java/org/springframework/xml/validation/XmlValidator.java
+++ b/xml/src/main/java/org/springframework/xml/validation/XmlValidator.java
@@ -22,10 +22,9 @@ import javax.xml.transform.Source;
import org.xml.sax.SAXParseException;
/**
- * Simple processor that validates a given Source. Can be created via the
- * XmlValidatorFactory.
+ * Simple processor that validates a given {@link Source}. Can be created via the {@link XmlValidatorFactory}.
*
XmlValidator instances are designed to be thread safe.
+ * Instances of this class are designed to be thread safe.
*
* @author Arjen Poutsma
* @see XmlValidatorFactory#createValidator(org.springframework.core.io.Resource,String)
@@ -34,8 +33,8 @@ import org.xml.sax.SAXParseException;
public interface XmlValidator {
/**
- * Validates the given Source, and returns an array of SAXParseExceptions as result. The
- * array will be empty if no validation errors are found.
+ * Validates the given {@link Source}, and returns an array of {@link SAXParseException}s as result. The array will
+ * be empty if no validation errors are found.
*
* @param source the input document
* @return an array of SAXParseExceptions
@@ -44,4 +43,4 @@ public interface XmlValidator {
*/
SAXParseException[] validate(Source source) throws IOException;
-}
+}
\ No newline at end of file
diff --git a/xml/src/main/java/org/springframework/xml/validation/XmlValidatorFactory.java b/xml/src/main/java/org/springframework/xml/validation/XmlValidatorFactory.java
index 8b64c53f..8869d8d4 100644
--- a/xml/src/main/java/org/springframework/xml/validation/XmlValidatorFactory.java
+++ b/xml/src/main/java/org/springframework/xml/validation/XmlValidatorFactory.java
@@ -17,6 +17,7 @@
package org.springframework.xml.validation;
import java.io.IOException;
+import javax.xml.validation.Validator;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
@@ -25,11 +26,11 @@ import org.springframework.util.Assert;
import org.springframework.xml.JaxpVersion;
/**
* Factory for XmlValidators, being aware of JAXP 1.3 XmlValidators, and JAXP 1.0 parsing
* capababilities. Mainly for internal use within the framework.
*
* The goal of this class is to avoid runtime dependencies on JAXP 1.3 by using the best validation implementation that
- * is available. Prefers JAXP 1.3 XmlValidator implementations to a custom, SAX-based implementation.
+ * is available. Prefers JAXP 1.3 {@link XmlValidator} implementations to a custom, SAX-based implementation.
*
* @author Arjen Poutsma
* @see XmlValidator
@@ -46,8 +47,8 @@ public abstract class XmlValidatorFactory {
public static final String SCHEMA_RELAX_NG = "http://relaxng.org/ns/structure/1.0";
/**
- * Create a XmlValidator with the given schema resource and schema language type. The schema language
- * must be one of the SCHEMA_XXX constants.
+ * Create a {@link XmlValidator} with the given schema resource and schema language type. The schema language must
+ * be one of the SCHEMA_XXX constants.
*
* @param schemaResource a resource that locates the schema to validate against
* @param schemaLanguage the language of the schema
@@ -64,8 +65,8 @@ public abstract class XmlValidatorFactory {
}
/**
- * Create a XmlValidator with the given schema resources and schema language type. The schema language
- * must be one of the SCHEMA_XXX constants.
+ * Create a {@link XmlValidator} with the given schema resources and schema language type. The schema language must
+ * be one of the SCHEMA_XXX constants.
*
* @param schemaResources an array of resource that locate the schemas to validate against
* @param schemaLanguage the language of the schemas
@@ -25,11 +26,11 @@ import org.springframework.util.Assert;
import org.springframework.xml.JaxpVersion;
/**
- * Factory for XmlValidators, being aware of JAXP 1.3 XmlValidators, and JAXP 1.0 parsing
+ * Factory for {@link XmlValidator} objects, being aware of JAXP 1.3 {@link Validator}s, and JAXP 1.0 parsing
* capababilities. Mainly for internal use within the framework.
*